@@ -1,9 +1,11 @@
 pub mod macros;
 
+#[cfg(feature = "colored")]
 use crossterm::{
     execute,
     style::{Attribute, Color, Print, ResetColor, SetAttribute, SetForegroundColor},
 };
+
 use std::io;
 
 #[cfg(feature = "persistent")]
@@ -20,8 +22,8 @@ mod impls {
 #[cfg(test)]
 pub mod test;
 
-pub fn log<T: AsRef<str>>(color: Color, prefix: &str, msg: T) -> io::Result<()> {
-    print_log(color, prefix, &msg)?;
+pub fn log<T: AsRef<str>>(#[cfg(feature = "colored")] color: Color, prefix: &str, msg: T) -> io::Result<()> {
+    print_log(#[cfg(feature = "colored")] color, prefix, &msg)?;
 
     #[cfg(feature = "persistent")]
     if persistent::check_env() {
@@ -30,8 +32,9 @@ pub fn log<T: AsRef<str>>(color: Color, prefix: &str, msg: T) -> io::Result<()>
     Ok(())
 }
 
-fn print_log<T: AsRef<str>>(color: Color, prefix: &str, msg: &T) -> io::Result<()> {
-    execute!(
+fn print_log<T: AsRef<str>>(#[cfg(feature = "colored")] color: Color, prefix: &str, msg: &T) -> io::Result<()> {
+    #[cfg(feature = "colored")] 
+    return execute!(
         io::stderr().lock(),
         Print("["),
         SetAttribute(Attribute::Bold),
@@ -41,5 +44,12 @@ fn print_log<T: AsRef<str>>(color: Color, prefix: &str, msg: &T) -> io::Result<(
         Print("]: "),
         Print(msg.as_ref()),
         Print('\n')
-    )
+    );
+    
+    #[cfg(not(feature = "colored"))]
+    {
+        use std::io::Write;
+        writeln!(io::stderr().lock(), "[ {prefix} ]: {}", msg.as_ref())
+            .map(|_| ())
+    }
 }
